@@ -53,7 +53,7 @@ class DatabaseController:
         TODO: move database path to constants
         :arg
         """
-        engine = create_engine(DatabaseConfiguration().DataBaseConnectionString, echo=True)
+        engine = create_engine(DatabaseConfiguration().DataBaseConnectionString)
         Base.metadata.create_all(engine)
         return engine
 
