@@ -1,18 +1,17 @@
 import shutil
 from sqlalchemy.sql import text
-from FreeTAKServer.model.SQLAlchemy.Root import Base
 
 class TableController:
     # default constructor  def __init__(self):
     def __init__(self):
-        self.table: Base = object  # all inheriting methods MUST implement this variable
+        self.table = None
 
 
     def delete(self, session, query):
         # this function removes a row from the datapackages table based on the uid
         session.query(self.table).filter(text(query)).delete(synchronize_session='fetch')
         session.commit()
-        return 1
+
 
     def create(self, session, **args):
         # this function adds a new row to the datapackages table
@@ -22,12 +21,8 @@ class TableController:
 
     def query(self, session, query, columns):
         # query needs to be applicable to datapackage object tuple(['DataPackage.'+x for x in columns])
-        if isinstance(query, str): 
-            output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
-                text(query)).all()
-        elif isinstance(query, object):
-            output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
-                query).all()
+        output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
+            text(query)).all()
         return output
 
 
@@ -37,4 +32,4 @@ class TableController:
         for dp in DataPackages:
             for column, value in column_value.items():
                 setattr(dp, column, value)
-        session.commit()
+        session.commit()
\ No newline at end of file
