@@ -7,14 +7,11 @@ loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendGeoChatController").getLogger()
 
 class SendGeoChatController(SendCoTAbstractController):
-    def __init__(self, RawCoT=None):
+    def __init__(self, RawCoT):
         try:
             tempObject = super().Event.GeoChat()
             object = SendGeoChat()
-            if RawCoT is not None:
-                self.fill_object(object, tempObject, RawCoT)
-            else:
-                pass
+            self.fill_object(object, tempObject, RawCoT)
         except Exception as e:
             logger.error("there has been an exception in the creation"
                          " of the send Geo Chat object " + str(e))
