@@ -13,7 +13,6 @@ class ContactVariables:
         cls.ICONSETPATH = None
         cls.UID = None
         cls.NAME = None
-        cls.PHONE = None
         return cls
 
     @classmethod
@@ -47,40 +46,5 @@ class ContactVariables:
     def UserUpdate(cls):
         cls.endpoint = None
         cls.phone = None
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def SimpleCoT(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def Presence(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def Route(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def VideoStream(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def DroneSensor(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def SPISensor(cls):
-        cls.callsign = None
-        return cls
-
-    @classmethod
-    def BitsImageryVideo(cls):
         cls.callsign = None
         return cls
\ No newline at end of file
