@@ -47,9 +47,9 @@ class EventVariables:
     @classmethod
     def emergency_on(cls):
         cls.VERSIONNUM = '2.0'
-        cls.UID = None
-        cls.TYPE = "b-a-o-tbl"
-        cls.HOW = 'm-g'
+        cls.UID = 'RANDOM'
+        cls.TYPE = "DEFAULT"
+        cls.HOW = None
         cls.TIME = None
         cls.START = None
         cls.STALE = None
@@ -60,7 +60,7 @@ class EventVariables:
         cls.VERSIONNUM = '2.0'
         cls.UID = 'RANDOM'
         cls.TYPE = "DEFAULT"
-        cls.HOW = 'h-e'
+        cls.HOW = None
         cls.TIME = None
         cls.START = None
         cls.STALE = None
@@ -119,49 +119,4 @@ class EventVariables:
         cls.time = None
         cls.start = None
         cls.stale = None
-        return cls
-
-    @classmethod
-    def SimpleCoT(cls):
-        cls.version = "2.0"
-        cls.uid = None
-        cls.type = None
-        cls.time = None
-        cls.start = None
-        cls.stale = None
-        cls.how = None
-        return cls
-
-    @classmethod
-    def Presence(cls):
-        cls.version = "2.0"
-        cls.uid = None
-        cls.type = None
-        cls.time = None
-        cls.start = None
-        cls.stale = None
-        cls.how = None
-        return cls
-
-    @classmethod
-    def ExcheckUpdate(cls):
-        cls.version = None
-        cls.uid = None
-        cls.type = "t-x-m-c"
-        cls.time = None
-        cls.start = None
-        cls.stale = None
-        cls.how = "h-g-i-g-o"
-        return cls
-
-    @classmethod
-    def Route(cls):
-        cls.version = None
-        cls.uid = None
-        cls.type = "b-m-r"
-        cls.time = None
-        cls.start = None
-        cls.stale = None
-        cls.how = "h-e"
-        return cls
-
+        return cls
\ No newline at end of file
